@@ -6,7 +6,6 @@ from enum import Enum
 from . import Checks
 from . import IsDigit as ID
 from .CleanFolderData import Clean
-from .Colours import c
 from .Message import Message
 
 
@@ -14,9 +13,7 @@ class ModeEnum(Enum):
     int = "INT"
     yesno = "yn"
     str = "str"
-
-
-# Check if the input is a valid input using a whole bunch of data
+    path = "path"
 
 
 @dataclasses.dataclass
@@ -52,14 +49,14 @@ class Check:
 
         raise NotImplementedError(f"Mode: {mode} not implemented")
 
-    def getInput(self, msg: str, mode: ModeEnum, *, colour: str = "", **info):
+    def getInput(self, msg: str, mode: ModeEnum, callback=None, **info):
         """Translate the user input, through the check and returns
 
         Args:
             msg (str): The message to display to the user
             mode (ModeEnum): The check to run
-            colour (str, optional): The text colour of the message. Defaults to "".
             info (Multipile): Other arguments for some checks
+            callback (function): Callback after result has been entered
 
         Returns:
             _type_: The result of the check
@@ -78,13 +75,15 @@ class Check:
 
         check = None
         while check is None:
-            check = input(f"{c(colour)}{msg}{c()}")
+            check = input(msg)
 
             result = self.__translate_Mode(check, mode.value, **info)
             if result is None:
                 check = None
                 continue
 
+            if callable(callback):
+                return callback(result)
             return result
 
         # If check is none, just send it back i suppose.
