@@ -2,6 +2,7 @@ import os
 import time
 import typing
 
+from dataclasses import dataclass
 from . import Colours
 from .Check import Check
 from .Message import Message
@@ -13,6 +14,12 @@ except ModuleNotFoundError:
     canRead = False
 
 
+@dataclass
+class Numbers:
+    high: int = 2_147_483_648
+    low: int = -2_147_483_648
+
+
 class Display:
     """The main class to give the user an option"""
 
@@ -25,10 +32,18 @@ class Display:
         self.options: typing.Dict = {}  # specific formaat.
         self.__storedText = None
         self.gridData = []
-        self.__highest: int = 2_147_483_648
-        self.__lowest: int = -2_147_483_648
+        self.__Number = Numbers()
         self.chk: Check = Check()
         self.cursorPosition = [0, 0]
+        self.outMsg = None
+
+    def SetQuitMessage(self, msg: str):
+        """Set the message to show on output
+
+        Args:
+            msg (str): The message to show
+        """
+        self.outMsg = msg
 
     def SetOptions(self, options: typing.Dict):
         """Set the program options
@@ -105,7 +120,8 @@ class Display:
             pace: (int, optional): Words per second to show using typewritter effect.Defaults to 100
         """
         print(
-            f"{Colours.Fore.GREEN}{'-' * os.get_terminal_size().columns}{Colours.Fore.RESET}")
+            f"{Colours.Fore.GREEN}{'-' * os.get_terminal_size().columns}{Colours.Fore.RESET}"
+        )
 
         if typewriter:
             for i in text:
@@ -116,7 +132,8 @@ class Display:
             print(text)
 
         print(
-            f"{Colours.Fore.GREEN}{'-' * os.get_terminal_size().columns}{Colours.Fore.RESET}")
+            f"{Colours.Fore.GREEN}{'-' * os.get_terminal_size().columns}{Colours.Fore.RESET}"
+        )
 
         self.__storedText = text
 
@@ -161,7 +178,7 @@ class Display:
 
 Controls:
 ---------------------------------------------------------
-W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
+W/Up: Up, A/Left: Left, S/Down: Down, D/Right: Right, Q: Quit, Enter: Select"""
         )
 
     def __ShowList(self):
@@ -174,11 +191,11 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
                 continue
 
             print(f"{opt:5}:{optionList.get(opt)[1]}")
-            self.__highest = opt
+            self.__Number.high = opt
 
         print()
 
-        self.__lowest = negList[0]
+        self.__Number.low = negList[0]
         negList = reversed(negList)
         for item in negList:
             print(f"{item:5}:{optionList.get(item)[1]}")
@@ -188,8 +205,8 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
             v = self.chk.getInput(
                 "Please enter the number you want to select: ",
                 "INT",
-                lower=self.__lowest,
-                higher=self.__highest,
+                lower=self.__Number.low,
+                higher=self.__Number.high,
             )
             return self.options.get(v)[0](self.options.get(v)[1:])
         except TypeError:
@@ -236,25 +253,25 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
         chosen = False
         while not chosen:
             k = readkey().lower()
-            if k == "w":
+            if k in ("w", key.UP):
                 self.cursorPosition[1] -= 1
                 # Lock
                 if self.cursorPosition[1] < 0:
                     self.cursorPosition[1] = 0
 
-            elif k == "a":
+            elif k in ("a", key.LEFT):
                 self.cursorPosition[0] -= 1
                 # Lock
                 if self.cursorPosition[0] < 0:
                     self.cursorPosition[0] = 0
 
-            elif k == "s":
+            elif k in ("s", key.DOWN):
                 self.cursorPosition[1] += 1
                 # lock
                 if self.cursorPosition[1] > len(self.gridData) - 1:
                     self.cursorPosition[1] = len(self.gridData) - 1
 
-            elif k == "d":
+            elif k in ("d", key.RIGHT):
                 self.cursorPosition[0] += 1
                 # Lock
                 if (
@@ -279,9 +296,11 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
 
             elif k == "q":
                 chosen = True
-                return None
+                return self.outMsg
 
             # moves the cursor, Makes it look clearer
             print("\033[0;0H", end="")
             self.ShowHeader(text=self.__storedText)
             self.__ShowGrid()
+
+        return None
